@@ -35,9 +35,11 @@
 #' @param lito_min_bracket The taxable income at which the value of the offset starts to reduce (from \code{lito_max_offset}).
 #' @param lito_multi A list of two components, named \code{x} and \code{y}, giving the value of a \emph{replacement} for \code{lito} at specified points, which will be linked by a piecewise linear curve between the points specified. For example, to mimic LITO in 2015-16 (when the offset was \$445 for incomes below \$37,000, and afterwards tapered off to \$66,667), one would use \code{lito_multi = list(x = c(-Inf, 37e3, 200e3/3, Inf), y = c(445, 445, 0, 0))}. The reason the argument ends with \code{multi} is that it is intended to extend the original parameters of LITO so that multiple kinks (including ones of positive and negative gradients) can be modelled. 
 #' 
-#' @param Budget2018_lamington The Low Middle Income Tax Offset proposed in the 2018 Budget.
+#' @param Budget2018_lamington logical; default is `FALSE`. If set to `TRUE`, calculates the amount that taxpayers would be entitled to under the Low and Middle Income Tax Offset as contained in the 2018 Budget.
+#' @param Budget2019_lamington logical; default is `FALSE`. If set to `TRUE`, calculates the amount that taxpayers would be entitled to under the Low and Middle Income Tax Offset as amended by the 2019 Budget.
 #' @param Budget2018_lito_202223 The LITO proposed for 2022-23 proposed in the 2018 Budget.
-#' @param Budget2018_watr The "Working Australian Tax Refund" proposed in the Opposition Leader's Budget Reply Speech 2018.
+#' @param Budget2018_watr logical; default is `FALSE`. If set to `TRUE`, calculates the "Working Australian Tax Refund" as proposed in the Labor Opposition Leader's Budget Reply Speech 2018.
+#' @param Budget2019_watr logical; default is `FALSE`. If set to `TRUE`, calculates the "Working Australian Tax Refund" as revised in the Labor Opposition Leader's Budget Reply Speech 2019.
 #' 
 #' @param sapto_eligible Whether or not each taxpayer in \code{sample_file} is eligible for \code{SAPTO}. 
 #' If \code{NULL}, the default, then eligibility is determined by \code{age_range} in \code{sample_file};
@@ -111,8 +113,10 @@ model_income_tax <- function(sample_file,
                              lito_multi = NULL,
                              
                              Budget2018_lamington = FALSE,
+                             Budget2019_lamington = FALSE,
                              Budget2018_lito_202223 = FALSE,
                              Budget2018_watr = FALSE,
+                             Budget2019_watr = FALSE,
                              
                              sapto_eligible = NULL,
                              sapto_max_offset = NULL,
@@ -748,15 +752,28 @@ model_income_tax <- function(sample_file,
     }
     
     lamington_offset. <-
-      if (Budget2018_lamington) {
+      if  (Budget2018_lamington) {
         lmito(income, fy.year = baseline_fy)
-      } else {
-        0
+        
+      } else if (Budget2019_lamington){
+        lmito(income, 
+              fy.year = baseline_fy,
+              first_offset = 255,
+              thresholds = c(37e3, 48e3, 90e3, 126e3),
+              taper = c(0, 0.075, 0, -0.03))
+
+      }  else {
+          0
       }
     
     watr. <- 
       if (Budget2018_watr) {
         watr(income)
+      } else if (Budget2019_watr) {
+        watr(income,
+             first_offset = 350,
+             thresholds = c(37e3, 48e3, 90e3, 126e3),
+             taper = c(0, (1080-350)/11000, 0, -0.03))
       } else {
         0
       }
