@@ -57,11 +57,3 @@ NumericVector IncomeTax(NumericVector x, NumericVector thresholds, NumericVector
 }
 
 
-// You can include R code blocks in C++ files processed with sourceCpp
-// (useful for testing and development). The R code will be automatically 
-// run after the compilation.
-//
-
-/*** R
-timesTwo(42)
-*/
