@@ -67,14 +67,14 @@ test_that("As applied with inflators", {
                fixed = TRUE)
   expect_error(wage_inflator(from_fy = "2015-16", to_fy = "2020-21",
                              forecast.series = "custom",
-                             wage.series = list(fy_year = c("2016-17", "2017-18", "2019-20", "2018-19", "2020-21"),
-                                                r = 1:5/100)),
+                             wage.series = list(fy_year = c("2016-17", "2017-18", "2019-20", "2020-21","2018-19", "2020-21"),
+                                                r = 1:6/100)),
                regexp = '`wage.series$fy_year` had the required financial years but not in the correct order.',
                fixed = TRUE)
-  expect_error(wage_inflator(from_fy = "2015-16", to_fy = "2019-20",
+  expect_error(wage_inflator(from_fy = "2015-16", to_fy = "2020-21",
                              forecast.series = "custom",
-                             wage.series = list(fy_year = c("2019-20", "2018-19"),
-                                                r = 1:2/100)),
+                             wage.series = list(fy_year = c("2020-21", "2019-20", "2018-19"),
+                                                r = 1:3/100)),
                regexp = '`wage.series$fy_year` had the required financial years but not in the correct order.',
                fixed = TRUE)
   
